@@ -1,5 +1,5 @@
 package MIDI::Drummer::Tiny::Types;
-$MIDI::Drummer::Tiny::Types::VERSION = '0.6006';
+$MIDI::Drummer::Tiny::Types::VERSION = '0.6007';
 our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Type library for MIDI::Drummer::Tiny
@@ -10,26 +10,16 @@ use warnings;
 use Type::Library
     -extends => [ qw(
         Types::MIDI
-        Types::Common::Numeric
+        Types::Music
         Types::Common::String
     ) ],
     -declare => qw(
-        BPM
         Duration
     );
 use Type::Utils -all;
 
 use MIDI::Util qw(midi_dump);
 
-#pod =type BPM
-#pod
-#pod A L<positive number|Types::Common::Numeric/PositiveNum> expressing
-#pod beats per minute.
-#pod
-#pod =cut
-
-declare BPM, as PositiveNum;
-
 #pod =type Duration
 #pod
 #pod A L<non-empty string|Types::Common::String/Types> corresponding to
@@ -54,15 +44,10 @@ MIDI::Drummer::Tiny::Types - Type library for MIDI::Drummer::Tiny
 
 =head1 VERSION
 
-version 0.6006
+version 0.6007
 
 =head1 TYPES
 
-=head2 BPM
-
-A L<positive number|Types::Common::Numeric/PositiveNum> expressing
-beats per minute.
-
 =head2 Duration
 
 A L<non-empty string|Types::Common::String/Types> corresponding to
